@@ -1,11 +1,14 @@
 """
 The default group of operations that pyflexebs has
 """
+import logging
+import time
 
 from pytconf.config import register_endpoint, register_function_group
 
 import pyflexebs
 import pyflexebs.version
+from pyflexebs.configs import ConfigInterval
 
 GROUP_NAME_DEFAULT = "default"
 GROUP_DESCRIPTION_DEFAULT = "all pyflexebs commands"
@@ -29,3 +32,16 @@ def version() -> None:
     Print version
     """
     print(pyflexebs.version.VERSION_STR)
+
+
+@register_endpoint(
+    group=GROUP_NAME_DEFAULT,
+)
+def daemon() -> None:
+    """
+    Run daemon and monitor disk utilization
+    """
+    logger = logging.getLogger(__name__)
+    while True:
+        time.sleep(ConfigInterval.interval)
+        logger.info("checking disk utilization")
